@@ -28,6 +28,6 @@ def get_host():
                 return host
     except:
         pass
-    return 'http://data.rainiee.com:8001'
+    return 'http://47.102.221.162:8001'
 
 
